@@ -4,7 +4,7 @@ Created on: Dec 04, 2014
 @author: qwang
 '''
 
-def group_user(locale, did):
+def group_user(did, locale):
     '''
     Use did to group user, return number between 1 to 16 as group index.
     '''
